#
# spec file for package ghc-typed-process
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name typed-process
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.2.13.0
Release:        1.3
Summary:        Run external processes, with strong typing of streams
License:        MIT
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-async-devel
BuildRequires:  ghc-async-prof
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-process-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-stm-devel
BuildRequires:  ghc-stm-prof
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-transformers-prof
BuildRequires:  ghc-unliftio-core-devel
BuildRequires:  ghc-unliftio-core-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-base64-bytestring-devel
BuildRequires:  ghc-base64-bytestring-prof
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-hspec-prof
BuildRequires:  ghc-temporary-devel
BuildRequires:  ghc-temporary-prof
%endif

%description
Please see the tutorial at <https://github.com/fpco/typed-process#readme>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc ChangeLog.md README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Sat Apr 12 2025 Peter Simons <psimons@suse.com>
- Update typed-process to version 0.2.13.0.
  [#]# 0.2.13.0
  * Format stdout and stderr in `ExitCodeException` assuming they are in
    UTF-8.  See [#87](https://github.com/fpco/typed-process/pull/87).
    Thanks to @9999years for the legwork on this change.
* Wed Aug 21 2024 Peter Simons <psimons@suse.com>
- Update typed-process to version 0.2.12.0.
  [#]# 0.2.12.0
  * Add `getPid`, `exitCodeExceptionWithOutput`,
    `exitCodeExceptionNoOutput`,
  * Re-export `System.Process.Pid`
  * Thanks to Rebecca Turner @9999years
* Sun Oct  8 2023 Peter Simons <psimons@suse.com>
- Update typed-process to version 0.2.11.1.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/typed-process-0.2.11.1/src/ChangeLog.md
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Sun Feb 26 2023 Peter Simons <psimons@suse.com>
- Update typed-process to version 0.2.11.0.
  [#]# 0.2.11.0
  * Expose `System.Process.Typed.Internal`
* Fri Jun  3 2022 Peter Simons <psimons@suse.com>
- Update typed-process to version 0.2.10.1.
  [#]# 0.2.10.0
  * Add `mkPipeStreamSpec`
  [#]# 0.2.9.0
  * Re-export `StdStream`
* Sat Nov 27 2021 Peter Simons <psimons@suse.com>
- Update typed-process to version 0.2.8.0.
  [#]# 0.2.8.0
  * Re-export `ExitCode`, `ExitSuccess` and `ExitFailure`.
* Mon Nov  1 2021 psimons@suse.com
- Update typed-process to version 0.2.7.0.
  [#]# 0.2.7.0
  * Include empty argument in the show instance.
* Thu Oct  7 2021 psimons@suse.com
- Update typed-process to version 0.2.6.3.
  [#]# 0.2.6.3
  * Doc improvements
  [#]# 0.2.6.2
  * Doc improvements
* Fri Aug 13 2021 psimons@suse.com
- Update typed-process to version 0.2.6.1.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/typed-process-0.2.6.1/src/ChangeLog.md
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Thu Jul  4 2019 psimons@suse.com
- Update typed-process to version 0.2.6.0.
  [#]# Unreleased
  * The cleanup thread applies an `unmask` to the actions which wait for a
    process to exit, allowing the action to be interruptible.
* Thu Jun 27 2019 psimons@suse.com
- Update typed-process to version 0.2.5.0.
  [#] ChangeLog for typed-process
  [#]# 0.2.5.0
  * Add a `nullStream` [#24](https://github.com/fpco/typed-process/pull/24)
  * Add `withProcessWait`, `withProcessWait_`, `withProcessTerm`, and `withProcessTerm_`
    [#25](https://github.com/fpco/typed-process/issues/25)
* Sat Jun  8 2019 psimons@suse.com
- Update typed-process to version 0.2.4.1.
  [#]# 0.2.4.1
  * Fix a `Handle` leak in `withProcessInterleave` and its derivatives.
* Thu Jan 17 2019 psimons@suse.com
- Update typed-process to version 0.2.4.0.
  [#]# 0.2.4.0
  * Add `readProcessInterleaved` and `readProcessInterleaved_` to support
    capturing output from stdout and stderr in a single ByteString value.
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Fri Aug 17 2018 psimons@suse.com
- Update typed-process to version 0.2.3.0.
  [#]# 0.2.3.0
  * Add support for the single-threaded runtime via polling
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Mon May 14 2018 psimons@suse.com
- Update typed-process to version 0.2.2.0.
  * Add inherit versions of setter functions
  * Add `readProcessStdout`, `readProcessStdout_`, `readProcessStderr`, and `readProcessStderr_`
  * Do not show modified environment information in exceptions
  * Remove dependency on `conduit` and `conduit-extra`. Relevant code added to
    `Data.Conduit.Process.Typed` in `conduit-extra-1.2.1`.
  * Introduce 'unsafeProcessHandle' function
  * Fix bug in `waitForProcess` that caused exit code to be lost
  * Minor doc improvements
* Fri Mar 31 2017 psimons@suse.com
- Improve package description.
* Sun Feb  5 2017 psimons@suse.com
- Update to version 0.1.0.0 with cabal2obs.
